@@ -210,9 +210,7 @@ class ExecutionContext:
         self.type_resolver = type_resolver  # type: ignore
         self.errors = errors
         self.middleware_manager = middleware_manager
-        self._subfields_cache: Dict[
-            Tuple[GraphQLObjectType, int], Dict[str, List[FieldNode]]
-        ] = {}
+        self._subfields_cache: Dict[Tuple, Dict[str, List[FieldNode]]] = {}
 
     @classmethod
     def build(
@@ -395,9 +393,7 @@ class ExecutionContext:
                     return awaited_results
 
                 # noinspection PyTypeChecker
-                results = await_and_set_result(
-                    cast(Awaitable, results), response_name, result
-                )
+                results = await_and_set_result(results, response_name, result)
             elif isawaitable(result):
                 # noinspection PyShadowingNames
                 async def set_result(results, response_name, result):
@@ -628,17 +624,13 @@ class ExecutionContext:
                 async def await_result():
                     try:
                         return await result
-                    except GraphQLError as error:
-                        return error
                     except Exception as error:
-                        return GraphQLError(str(error), original_error=error)
+                        return error
 
                 return await_result()
             return result
-        except GraphQLError as error:
-            return error
         except Exception as error:
-            return GraphQLError(str(error), original_error=error)
+            return error
 
     def complete_value_catching_error(
         self,
@@ -792,7 +784,7 @@ class ExecutionContext:
         info: GraphQLResolveInfo,
         path: Path,
         result: Iterable[Any],
-    ) -> AwaitableOrValue[Any]:
+    ) -> AwaitableOrValue[List[Any]]:
         """Complete a list value.
 
         Complete a list value by completing each item in the list with the inner type.
@@ -887,7 +879,7 @@ class ExecutionContext:
                     result,
                 )
                 if isawaitable(value):
-                    return await value  # type: ignore
+                    return await value
                 return value
 
             return await_complete_object_value()
@@ -995,10 +987,20 @@ class ExecutionContext:
         subfields are not repeatedly calculated, which saves overhead when resolving
         lists of values.
         """
-        # Use id(field_nodes) as key, since a list cannot be hashed and
-        # (after conversion to a tuple) hashing nodes would be too slow:
-        cache_key = return_type, id(field_nodes)
-        sub_field_nodes = self._subfields_cache.get(cache_key)
+        cache = self._subfields_cache
+        # We cannot use the field_nodes themselves as key for the cache, since they
+        # are not hashable as a list. We also do not want to use the field_nodes
+        # themselves (converted to a tuple) as keys, since hashing them is slow.
+        # Therefore we use the ids of the field_nodes as keys. Note that we do not
+        # use the id of the list, since we want to hit the cache for all lists of
+        # the same nodes, not only for the same list of nodes. Also, the list id may
+        # even be reused, in which case we would get wrong results from the cache.
+        key = (
+            (return_type, id(field_nodes[0]))
+            if len(field_nodes) == 1  # optimize most frequent case
+            else tuple((return_type, *map(id, field_nodes)))
+        )
+        sub_field_nodes = cache.get(key)
         if sub_field_nodes is None:
             sub_field_nodes = {}
             visited_fragment_names: Set[str] = set()
@@ -1011,7 +1013,7 @@ class ExecutionContext:
                         sub_field_nodes,
                         visited_fragment_names,
                     )
-            self._subfields_cache[cache_key] = sub_field_nodes
+            cache[key] = sub_field_nodes
         return sub_field_nodes
 
 
@@ -1112,7 +1114,7 @@ def default_type_resolver(
             is_type_of_result = type_.is_type_of(value, info)
 
             if isawaitable(is_type_of_result):
-                append_awaitable_results(cast(Awaitable, is_type_of_result))
+                append_awaitable_results(is_type_of_result)
                 append_awaitable_types(type_)
             elif is_type_of_result:
                 return type_
@@ -1130,7 +1132,7 @@ def default_type_resolver(
     return None
 
 
-def default_field_resolver(source, info, **args):
+def default_field_resolver(source: Any, info: GraphQLResolveInfo, **args: Any) -> Any:
     """Default field resolver.
 
     If a resolve function is not given, then a default resolve behavior is used which
