@@ -268,7 +268,7 @@ def describe_type_system_schema():
             msg = str(exc_info.value)
             assert msg == (
                 "Schema must contain uniquely named types"
-                f" but contains multiple types named 'String'."
+                " but contains multiple types named 'String'."
             )
 
         def rejects_a_schema_which_defines_an_object_twice():
@@ -282,7 +282,7 @@ def describe_type_system_schema():
             msg = str(exc_info.value)
             assert msg == (
                 "Schema must contain uniquely named types"
-                f" but contains multiple types named 'SameName'."
+                " but contains multiple types named 'SameName'."
             )
 
         def rejects_a_schema_which_defines_fields_with_conflicting_types():
@@ -300,7 +300,7 @@ def describe_type_system_schema():
             msg = str(exc_info.value)
             assert msg == (
                 "Schema must contain uniquely named types"
-                f" but contains multiple types named 'SameName'."
+                " but contains multiple types named 'SameName'."
             )
 
         def describe_when_assumed_valid():
